==> mx-packageinstaller-pkglist_19.08.03.tar.xz: mx-packageinstaller-pkglist/gimp_basic.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
GIMP Basic
</name>

<description>
   <am>advanced picture editor - installs GIMP only</am>
   <ar>advanced picture editor - installs GIMP only</ar>
   <bg>advanced picture editor - installs GIMP only</bg>
   <ca>editor gràfic avançat; instal·la només GIMP</ca>
   <cs>advanced picture editor - installs GIMP only</cs>
   <da>avanceret billedredigering - installerer kun GIMP</da>
   <de>Erweiterter Bildeditor - installiert nur GIMP</de>
   <el>επεξεργαστή εικόνων - εγκαθιστά μόνο το GIMP</el>
   <en>advanced picture editor - installs GIMP only</en>
   <es>Editor de imágenes avanzado. Instala GIMP solamente.</es>
   <et>advanced picture editor - installs GIMP only</et>
   <eu>advanced picture editor - installs GIMP only</eu>
   <fa>advanced picture editor - installs GIMP only</fa>
   <fi>advanced picture editor - installs GIMP only</fi>
   <fr>Éditeur d'image avancé - installe Gimp uniquement</fr>
   <he_IL>advanced picture editor - installs GIMP only</he_IL>
   <hi>advanced picture editor - installs GIMP only</hi>
   <hr>advanced picture editor - installs GIMP only</hr>
   <hu>advanced picture editor - installs GIMP only</hu>
   <id>advanced picture editor - installs GIMP only</id>
   <is>advanced picture editor - installs GIMP only</is>
   <it>Editor di immagini avanzato - installa solo GIMP</it>
   <ja_JP>advanced picture editor - installs GIMP only</ja_JP>
   <ja>advanced picture editor - installs GIMP only</ja>
   <kk>advanced picture editor - installs GIMP only</kk>
   <ko>advanced picture editor - installs GIMP only</ko>
   <lt>išplėstinis paveikslų redaktorius - įdiegia tik GIMP</lt>
   <mk>advanced picture editor - installs GIMP only</mk>
   <nb>advanced picture editor - installs GIMP only</nb>
   <nl>geavanceerde foto-editor - installeert alleen GIMP</nl>
   <pl>zaawansowany edytor grafiki i zdjęć - instaluje tylko program GIMP</pl>
   <pt_BR>advanced picture editor - installs GIMP only</pt_BR>
   <pt>editor de imagem avançado - instala apenas o GIMP</pt>
   <ro>advanced picture editor - installs GIMP only</ro>
   <ru>Продвинутый графический редактор - установка только GIMP</ru>
   <sk>advanced picture editor - installs GIMP only</sk>
   <sl>advanced picture editor - installs GIMP only</sl>
   <sq>advanced picture editor - installs GIMP only</sq>
   <sr>advanced picture editor - installs GIMP only</sr>
   <sv>avancerad bildredigerare - installerar enbart GIMP</sv>
   <tr>advanced picture editor - installs GIMP only</tr>
   <uk>розширений редактор зображень - встановлює лише GIMP</uk>
   <zh_CN>advanced picture editor - installs GIMP only</zh_CN>
   <zh_TW>advanced picture editor - installs GIMP only</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/005/024/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
gimp
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
gimp
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.09.03.tar.xz: mx-packageinstaller-pkglist/gimp_basic.pm <==
<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
GIMP Basic
</name>

<description>
   <am>advanced picture editor - installs GIMP only</am>
   <ar>advanced picture editor - installs GIMP only</ar>
   <bg>advanced picture editor - installs GIMP only</bg>
   <ca>editor gràfic avançat; instal·la només GIMP</ca>
   <cs>advanced picture editor - installs GIMP only</cs>
   <da>avanceret billedredigering - installerer kun GIMP</da>
   <de>Erweiterter Bildeditor - installiert nur GIMP</de>
   <el>επεξεργαστή εικόνων - εγκαθιστά μόνο το GIMP</el>
   <en>advanced picture editor - installs GIMP only</en>
   <es>Editor de imágenes avanzado. Instala GIMP solamente.</es>
   <et>advanced picture editor - installs GIMP only</et>
   <eu>advanced picture editor - installs GIMP only</eu>
   <fa>advanced picture editor - installs GIMP only</fa>
   <fi>advanced picture editor - installs GIMP only</fi>
   <fr>Éditeur d'image avancé - installe Gimp uniquement</fr>
   <he_IL>advanced picture editor - installs GIMP only</he_IL>
   <hi>advanced picture editor - installs GIMP only</hi>
   <hr>advanced picture editor - installs GIMP only</hr>
   <hu>advanced picture editor - installs GIMP only</hu>
   <id>advanced picture editor - installs GIMP only</id>
   <is>advanced picture editor - installs GIMP only</is>
   <it>Editor di immagini avanzato - installa solo GIMP</it>
   <ja_JP>advanced picture editor - installs GIMP only</ja_JP>
   <ja>advanced picture editor - installs GIMP only</ja>
   <kk>advanced picture editor - installs GIMP only</kk>
   <ko>advanced picture editor - installs GIMP only</ko>
   <lt>išplėstinis paveikslų redaktorius - įdiegia tik GIMP</lt>
   <mk>advanced picture editor - installs GIMP only</mk>
   <nb>advanced picture editor - installs GIMP only</nb>
   <nl>geavanceerde foto-editor - installeert alleen GIMP</nl>
   <pl>zaawansowany edytor grafiki i zdjęć - instaluje tylko program GIMP</pl>
   <pt_BR>Editor de imagem avançado - instala apenas o GIMP</pt_BR>
   <pt>Editor de imagem avançado - instala apenas o GIMP</pt>
   <ro>advanced picture editor - installs GIMP only</ro>
   <ru>Продвинутый графический редактор - установка только GIMP</ru>
   <sk>advanced picture editor - installs GIMP only</sk>
   <sl>napredni urejevalnik slik - namesti le GIMP</sl>
   <sq>advanced picture editor - installs GIMP only</sq>
   <sr>advanced picture editor - installs GIMP only</sr>
   <sv>avancerad bildredigerare - installerar enbart GIMP</sv>
   <tr>advanced picture editor - installs GIMP only</tr>
   <uk>розширений редактор зображень - встановлює лише GIMP</uk>
   <zh_CN>advanced picture editor - installs GIMP only</zh_CN>
   <zh_TW>advanced picture editor - installs GIMP only</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/005/024/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
gimp
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
gimp
</uninstall_package_names>
</app>
